@@ -257,7 +257,7 @@ sub fld {
 	foreach (@{$self->{'flds'}}) {
 		if ($_->name eq $fld) {return $_;}
 	}
-	die "Field not found: $fld";
+	confess "Field not found: $fld";
 }
 
 =head2 $table->got_fld($fld)
@@ -366,5 +366,76 @@ sub sql_create {
 	$self->db->sql_create_table($self)
 }
 
+=head2 $table->post_fmt($kind)
+
+Returns a fmt for viewing a post from this table in the 
+$kind format. It can be specified in ... FIXME: where?
+
+=cut
+
+sub post_fmt {
+	my ($self,$kind) =@_;
+	if (defined $kind && $kind eq 'view_text') {
+		my $res="";
+		foreach ($self->fld_names) {
+			$res.="$_: <fld $_>\n";
+		}
+		return $res;
+	} else {
+		my $res="<table>";
+		foreach my $fld ($self->fld_names) {
+			$res.="<tr><td valign=top><b>$fld</b></td><td><fld $fld></td></tr>\n";
+		}
+		$res.="</table>";
+		return $res;
+	}
+}
+
+=head2 $table->list_fmt($kind, $butt, $flds)
+
+Returns a fmt for viewing a set of posts from this table in the 
+$kind format. It can be specified in ... FIXME: where?
+
+The default fmt will consist of a table with one colume per Fld specified 
+in the arrayref $flds. If it is not defined all Fld will be viewed.
+
+$butt can be used to specify the contents of an extra colum to the right 
+of the rest. To for example contain the view, edit and delete buttons.
+
+=cut
+
+sub list_fmt {
+	my ($self, $kind, $butt, $flds) = @_;
+	if (defined $kind && $kind eq 'view_text') {
+		return "<node join=\"\n\"></node>";
+	} else {
+	  my $res="<table border=1>";
+  	my @flds;
+	
+	  if (defined $flds) {
+		  @flds=@$flds;
+  	} else {
+	  	@flds=$self->fld_names;
+  	}
+
+	  $res.="<tr>";
+  	foreach (@flds) {
+	  	$res.="<th>" . $_ . "</th>";
+  	}
+	  $res.="</tr>";
+
+  	$res.="<node><tr>";
+	  foreach (@flds) {
+		  $res.="<td><fld " . $_ . "></td>";
+  	}
+	  if (defined $butt) {
+		  $res.="<td>$butt</td>";
+  	}
+	  $res.="</tr></node>";
+
+  	$res.="</table>";
+	  return $res;
+	}
+}
 1;
 
